package
Version:
v1.20.3
Opens a new window with list of versions in this module.
Published: Aug 31, 2026
License: MIT
Opens a new window with license information.
Imports: 8
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type ExecutionResult struct {
Value any `json:"value"`
JSONString string `json:"json_string"`
SummaryText string `json:"summary_text"`
Logs []string `json:"logs"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.